@@ -1,35 +1,30 @@
 #ifndef GAME_H
 #define GAME_H
 
+//#define SOUND
+
 #include <kdebug.h>
 #include <klocale.h>
-#include <kpixmap.h>
-#include <arts/kplayobject.h>
-#include <arts/kartsserver.h>
-#include <arts/kartsdispatcher.h>
+#include <KConfigGroup>
 
 #include <math.h>
 
-#include <qcanvas.h>
-#include <qpainter.h>
-#include <qcolor.h>
-#include <qframe.h>
-#include <qlayout.h>
-#include <qmap.h>
-#include <qpen.h>
-#include <qpoint.h>
-#include <qpointarray.h>
-#include <qrect.h>
-#include <qstringlist.h>
-#include <qvaluelist.h>
+#include <QMap>
+#include <QPoint>
+#include <QRect>
+#include <QPixmap>
+#include <QKeyEvent>
+#include <QGraphicsScene>
 
 #include "object.h"
 #include "config.h"
+#include "kconfiggroup.h"
 #include "canvasitem.h"
 #include "ball.h"
 #include "statedb.h"
 #include "rtti.h"
-#include <kdemacros.h>
+#include <kolflib_export.h>
+#include "kolfsvgrenderer.h" 
 
 class QLabel;
 class QSlider;
@@ -37,22 +32,27 @@ class QCheckBox;
 class QTimer;
 class QKeyEvent;
 class QMouseEvent;
+class QResizeEvent;
+class QVBoxLayout;
 class QPainter;
+class QPrinter;
 class KConfig;
-class KPrinter;
 class KolfGame;
 
+namespace Phonon
+{
+    class MediaObject;
+}
+
 enum Direction { D_Left, D_Right, Forwards, Backwards };
 enum Amount { Amount_Less, Amount_Normal, Amount_More };
 enum HoleResult { Result_Holed, Result_Miss, Result_LipOut };
 
-class Player;
-
 class BallStateInfo
 {
 public:
-	void saveState(KConfig *cfg);
-	void loadState(KConfig *cfg);
+	void saveState(KConfigGroup *cfgGroup);
+	void loadState(KConfigGroup *cfgGroup);
 
 	int id;
 	QPoint spot;
@@ -60,7 +60,7 @@ public:
 	bool beginningOfHole;
 	int score;
 };
-class BallStateList : public QValueList<BallStateInfo>
+class BallStateList : public QList<BallStateInfo>
 {
 public:
 	int hole;
@@ -72,21 +72,21 @@ public:
 class Player
 {
 public:
-	Player() : m_ball(new Ball(0)) {};
+	Player() : m_ball(new Ball(0)) {}
 	Ball *ball() const { return m_ball; }
 	void setBall(Ball *ball) { m_ball = ball; }
-	BallStateInfo stateInfo(int hole) const { BallStateInfo ret; ret.spot = QPoint(m_ball->x(), m_ball->y()); ret.state = m_ball->curState(); ret.score = score(hole); ret.beginningOfHole = m_ball->beginningOfHole(); ret.id = m_id; return ret; }
+	BallStateInfo stateInfo(int hole) const { BallStateInfo ret; ret.spot = QPoint((int)m_ball->getBaseX(), (int)m_ball->getBaseY()); ret.state = m_ball->curState(); ret.score = score(hole); ret.beginningOfHole = m_ball->beginningOfHole(); ret.id = m_id; return ret; }
 
-	QValueList<int> scores() const { return m_scores; }
-	void setScores(const QValueList<int> &newScores) { m_scores = newScores; }
-	int score(int hole) const { return (*m_scores.at(hole - 1)); }
+	QList<int> scores() const { return m_scores; }
+	void setScores(const QList<int> &newScores) { m_scores = newScores; }
+	int score(int hole) const { return m_scores.at(hole - 1); }
 	int lastScore() const { return m_scores.last(); }
 	int firstScore() const { return m_scores.first(); }
 
-	void addStrokeToHole(int hole) { (*m_scores.at(hole - 1))++; }
-	void setScoreForHole(int score, int hole) { (*m_scores.at(hole - 1)) = score; }
-	void subtractStrokeFromHole(int hole) { (*m_scores.at(hole - 1))--; }
-	void resetScore(int hole) { (*m_scores.at(hole - 1)) = 0; }
+	void addStrokeToHole(int hole) { (*(m_scores.begin() + (hole -1)))++; }
+	void setScoreForHole(int score, int hole) { (*(m_scores.begin() + (hole - 1))) = score; }
+	void subtractStrokeFromHole(int hole) { (*(m_scores.begin() + (hole -1))--); }
+	void resetScore(int hole) { (*(m_scores.begin() + (hole - 1))) = 0; }
 	void addHole() { m_scores.append(0); }
 	unsigned int numHoles() const { return m_scores.count(); }
 
@@ -98,16 +98,24 @@ public:
 
 private:
 	Ball *m_ball;
-	QValueList<int> m_scores;
+	QList<int> m_scores;
 	QString m_name;
 	int m_id;
 };
-typedef QValueList<Player> PlayerList;
 
-class Arrow : public QCanvasLine
+typedef QList<Player> PlayerList;
+
+class AntialisedLine : public QGraphicsLineItem
 {
 public:
-	Arrow(QCanvas *canvas);
+	AntialisedLine(QGraphicsItem *parent, QGraphicsScene *scene);
+	void paint(QPainter *p, const QStyleOptionGraphicsItem *style, QWidget *widget);
+};
+
+class Arrow : public QGraphicsLineItem
+{
+public:
+	Arrow(QGraphicsItem * parent, QGraphicsScene *scene);
 	void setAngle(double newAngle) { m_angle = newAngle; }
 	double angle() const { return m_angle; }
 	void setLength(double newLength) { m_length = newLength; }
@@ -119,27 +127,33 @@ public:
 	void aboutToDie();
 	virtual void moveBy(double, double);
 	void updateSelf();
-	virtual void setZ(double newz);
+	virtual void setZValue(double newz);
 
 private:
+	/*
+	 * base numbers are the size or position when no resizing has taken place (i.e. the defaults)
+	 */
+	double baseLineThickness;
 	double m_angle;
 	double m_length;
 	bool m_reversed;
-	QCanvasLine *line1;
-	QCanvasLine *line2;
+	QGraphicsLineItem *line1;
+	QGraphicsLineItem *line2;
 };
 
 class RectPoint;
 class RectItem
 {
 public:
-	virtual void newSize(int /*width*/, int /*height*/) {};
+	virtual ~RectItem(){}
+	virtual void newSize(double /*width*/, double /*height*/) {}
+	virtual void updateBaseResizeInfo() {}
 };
 
-class RectPoint : public QCanvasEllipse, public CanvasItem
+class RectPoint : public QGraphicsEllipseItem, public CanvasItem
 {
 public:
-	RectPoint(QColor color, RectItem *, QCanvas *canvas);
+	RectPoint(const QColor &color, RectItem *, QGraphicsItem * parent, QGraphicsScene *scene);
 	void dontMove() { dontmove = true; }
 	virtual void moveBy(double dx, double dy);
 	virtual Config *config(QWidget *parent);
@@ -147,6 +161,8 @@ public:
 	virtual bool cornerResize() const { return true; }
 	virtual CanvasItem *itemToDelete() { return dynamic_cast<CanvasItem *>(rect); }
 	void setSizeFactor(double newFactor) { m_sizeFactor = newFactor; }
+	void setSize(double, double);
+	void updateBaseResizeInfo();
 
 protected:
 	RectItem *rect;
@@ -156,11 +172,13 @@ private:
 	bool dontmove;
 };
 
-class Ellipse : public QCanvasEllipse, public CanvasItem, public RectItem
+class KolfEllipse : public QGraphicsEllipseItem, public CanvasItem, public RectItem
 {
 public:
-	Ellipse(QCanvas *canvas);
+	KolfEllipse(QGraphicsItem * parent, QGraphicsScene *scene, const QString &type);
+	void firstMove(int x, int y);
 	virtual void advance(int phase);
+	void resize(double resizeFactor);
 
 	int changeEvery() const { return m_changeEvery; }
 	void setChangeEvery(int news) { m_changeEvery = news; }
@@ -171,18 +189,26 @@ public:
 	virtual void aboutToSave();
 	virtual void savingDone();
 
-	virtual QPtrList<QCanvasItem> moveableItems() const;
+	virtual QList<QGraphicsItem *> moveableItems() const;
+
+	virtual void newSize(double width, double height);
+	void setSize(double width, double height);
+	void paint(QPainter *painter, const QStyleOptionGraphicsItem *, QWidget *);
 
-	virtual void newSize(int width, int height);
 	virtual void moveBy(double dx, double dy);
 
 	virtual void editModeChanged(bool changed);
 
-	virtual void save(KConfig *cfg);
-	virtual void load(KConfig *cfg);
+	virtual void save(KConfigGroup *cfgGroup);
+	virtual void load(KConfigGroup *cfgGroup);
 
 	virtual Config *config(QWidget *parent);
 
+	double width() { return rect().width(); }
+	double height() { return rect().height(); }
+
+	void updateBaseResizeInfo();
+
 protected:
 	RectPoint *point;
 	int m_changeEvery;
@@ -191,13 +217,19 @@ protected:
 private:
 	int count;
 	bool dontHide;
+	/*
+	 * base numbers are the size or position when no resizing has taken place (i.e. the defaults)
+	 */
+	double baseX, baseY, baseHeight, baseWidth, resizeFactor;
+	QString type;
+	QPixmap pixmap;
 };
 class EllipseConfig : public Config
 {
 	Q_OBJECT
 
 public:
-	EllipseConfig(Ellipse *ellipse, QWidget *);
+	EllipseConfig(KolfEllipse *ellipse, QWidget *);
 
 private slots:
 	void value1Changed(int news);
@@ -215,102 +247,109 @@ private:
 	QLabel *fast2;
 	QSlider *slider1;
 	QSlider *slider2;
-	Ellipse *ellipse;
+	KolfEllipse *ellipse;
 };
 
-class Puddle : public Ellipse
+class Puddle : public KolfEllipse
 {
 public:
-	Puddle(QCanvas *canvas);
+	Puddle(QGraphicsItem * parent, QGraphicsScene *scene);
 	virtual bool collision(Ball *ball, long int id);
-	virtual int rtti() const { return Rtti_DontPlaceOn; }
 };
 class PuddleObj : public Object
 {
 public:
 	PuddleObj() { m_name = i18n("Puddle"); m__name = "puddle"; }
-	virtual QCanvasItem *newObject(QCanvas *canvas) { return new Puddle(canvas); }
+	virtual QGraphicsItem *newObject(QGraphicsItem * parent, QGraphicsScene *scene) { return new Puddle(parent, scene); }
 };
 
-class Sand : public Ellipse
+class Sand : public KolfEllipse
 {
 public:
-	Sand(QCanvas *canvas);
+	Sand(QGraphicsItem * parent, QGraphicsScene *scene);
 	virtual bool collision(Ball *ball, long int id);
 };
 class SandObj : public Object
 {
 public:
 	SandObj() { m_name = i18n("Sand"); m__name = "sand"; }
-	virtual QCanvasItem *newObject(QCanvas *canvas) { return new Sand(canvas); }
+	virtual QGraphicsItem *newObject(QGraphicsItem * parent, QGraphicsScene *scene) { return new Sand(parent, scene); }
 };
 
-class Inside : public QCanvasEllipse, public CanvasItem
+class Inside : public QGraphicsEllipseItem, public CanvasItem
 {
 public:
-	Inside(CanvasItem *item, QCanvas *canvas) : QCanvasEllipse(canvas) { this->item = item; }
+	Inside(CanvasItem *item, QGraphicsItem * parent, QGraphicsScene *scene) : QGraphicsEllipseItem(parent, scene) { this->item = item; }
 	virtual bool collision(Ball *ball, long int id) { return item->collision(ball, id); }
+	void setSize(double width, double height) { setRect(rect().x(), rect().y(), width, height); }
 
 protected:
 	CanvasItem *item;
 };
 
-class Bumper : public QCanvasEllipse, public CanvasItem
+class Bumper : public QGraphicsEllipseItem, public CanvasItem
 {
 public:
-	Bumper(QCanvas *canvas);
-
+	Bumper(QGraphicsItem * parent, QGraphicsScene *scene);
+	void paint(QPainter *painter, const QStyleOptionGraphicsItem * option, QWidget * widget);
 	virtual void advance(int phase);
-	virtual void aboutToDie();
-	virtual void moveBy(double dx, double dy);
-	virtual void editModeChanged(bool changed);
-
+	void moveBy(double x, double y);
+	void firstMove(int x, int y);
+	void resize(double resizeFactor);
 	virtual bool collision(Ball *ball, long int id);
+	void updateBaseResizeInfo();
 
 protected:
-	QColor firstColor;
-	QColor secondColor;
 	Inside *inside;
 
 private:
 	int count;
+	QPixmap pixmap;
+	bool pixmapInitialised;
+	/*
+	 * base numbers are the size or position when no resizing has taken place (i.e. the defaults)
+	 */
+	double resizeFactor, baseX, baseY;
+	int baseDiameter; 
 };
 class BumperObj : public Object
 {
 public:
 	BumperObj() { m_name = i18n("Bumper"); m__name = "bumper"; }
-	virtual QCanvasItem *newObject(QCanvas *canvas) { return new Bumper(canvas); }
+	virtual QGraphicsItem *newObject(QGraphicsItem * parent, QGraphicsScene *scene) { return new Bumper(parent, scene); }
 };
 
-class Hole : public QCanvasEllipse, public CanvasItem
+ class Cup :  public QGraphicsEllipseItem, public CanvasItem 
 {
 public:
-	Hole(QColor color, QCanvas *canvas);
-	virtual bool place(Ball * /*ball*/, bool /*wasCenter*/) { return true; };
-
-	virtual bool collision(Ball *ball, long int id);
-
-protected:
-	virtual HoleResult result(const QPoint, double, bool *wasCenter);
-};
-
-class Cup : public Hole
-{
-public:
-	Cup(QCanvas *canvas);
+	Cup(QGraphicsItem * parent, QGraphicsScene *scene);
+	void paint(QPainter *painter, const QStyleOptionGraphicsItem *, QWidget *);
 	virtual bool place(Ball *ball, bool wasCenter);
-	virtual void save(KConfig *cfg);
+	void moveBy(double x, double y);
+	void firstMove(int x, int y);
+	void resize(double resizeFactor);
+	virtual void save(KConfigGroup *cfgGroup);
+	void saveState(StateDB *db);
+	void loadState(StateDB *db);
 	virtual bool canBeMovedByOthers() const { return true; }
-	virtual void draw(QPainter &painter);
+	virtual bool collision(Ball *ball, long int id);
+	void updateBaseResizeInfo();
 
 protected:
 	QPixmap pixmap;
+	bool pixmapInitialised;
+	/*
+	 * base numbers are the size or position when no resizing has taken place (i.e. the defaults)
+	 */
+	double baseX, baseY, baseDiameter, resizeFactor;
+	virtual HoleResult result(const QPointF, double, bool *wasCenter);
 };
+
 class CupObj : public Object
 {
 public:
 	CupObj() { m_name = i18n("Cup"); m__name = "cup"; m_addOnNewHole = true; }
-	virtual QCanvasItem *newObject(QCanvas *canvas) { return new Cup(canvas); }
+	virtual QGraphicsItem *newObject(QGraphicsItem * parent, QGraphicsScene *scene) { return new Cup(parent, scene); }
 };
 
 class BlackHole;
@@ -329,11 +368,10 @@ private slots:
 private:
 	BlackHole *blackHole;
 };
-class BlackHoleExit : public QCanvasLine, public CanvasItem
+class BlackHoleExit : public AntialisedLine, public CanvasItem
 {
 public:
-	BlackHoleExit(BlackHole *blackHole, QCanvas *canvas);
-	virtual int rtti() const { return Rtti_NoCollision; }
+	BlackHoleExit(BlackHole *blackHole, QGraphicsItem * parent, QGraphicsScene *scene);
 	virtual void aboutToDie();
 	virtual void moveBy(double dx, double dy);
 	virtual bool deleteable() const { return false; }
@@ -343,11 +381,19 @@ public:
 	virtual void showInfo();
 	virtual void hideInfo();
 	void updateArrowAngle();
-	void updateArrowLength();
+	void updateArrowLength(double resizeFactor=1);
+	void setArrowPen(QPen pen) { arrow->setPen(pen); }
 	virtual Config *config(QWidget *parent);
 	BlackHole *blackHole;
+	double getBaseArrowPenThickness() { return baseArrowPenThickness; }
+	void updateBaseResizeInfo();
+	double resizeFactor, baseX, baseY;
 
 protected:
+	/*
+	 * base numbers are the size or position when no resizing has taken place (i.e. the defaults)
+	 */
+	double baseArrowPenThickness;
 	Arrow *arrow;
 };
 class BlackHoleTimer : public QObject
@@ -369,21 +415,23 @@ protected:
 	double m_speed;
 	Ball *m_ball;
 };
-class BlackHole : public QObject, public Hole
+class BlackHole : public QObject, public QGraphicsEllipseItem, public CanvasItem
 {
 Q_OBJECT
 
 public:
-	BlackHole(QCanvas *canvas);
+	BlackHole(QGraphicsItem * parent, QGraphicsScene *scene);
 	virtual bool canBeMovedByOthers() const { return true; }
+	void paint(QPainter *painter, const QStyleOptionGraphicsItem * option, QWidget * widget);
 	virtual void aboutToDie();
+	void resize(double resizeFactor);
 	virtual void showInfo();
 	virtual void hideInfo();
 	virtual bool place(Ball *ball, bool wasCenter);
-	virtual void save(KConfig *cfg);
-	virtual void load(KConfig *cfg);
+	virtual void save(KConfigGroup *cfgGroup);
+	virtual void load(KConfigGroup *cfgGroup);
 	virtual Config *config(QWidget *parent) { return new BlackHoleConfig(this, parent); }
-	virtual QPtrList<QCanvasItem> moveableItems() const;
+	virtual QList<QGraphicsItem *> moveableItems() const;
 	double minSpeed() const { return m_minSpeed; }
 	double maxSpeed() const { return m_maxSpeed; }
 	void setMinSpeed(double news) { m_minSpeed = news; exitItem->updateArrowLength(); }
@@ -395,10 +443,19 @@ public:
 	virtual void editModeChanged(bool editing) { exitItem->editModeChanged(editing); }
 	void updateInfo();
 
-	virtual void shotStarted() { runs = 0; };
+	virtual void shotStarted() { runs = 0; }
 
 	virtual void moveBy(double dx, double dy);
 
+        void setSize(double width, double height) { setRect(rect().x(), rect().y
+(), width, height); }
+        double width() { return rect().width(); }
+        double height() { return rect().height(); }
+
+	virtual bool collision(Ball *ball, long int id);
+
+	void updateBaseResizeInfo();
+
 public slots:
 	void eject(Ball *ball, double speed);
 	void halfway();
@@ -408,50 +465,69 @@ protected:
 	BlackHoleExit *exitItem;
 	double m_minSpeed;
 	double m_maxSpeed;
+	virtual HoleResult result(const QPointF, double, bool *wasCenter);
 
 private:
+	QPixmap pixmap;
+	bool pixmapInitialised;
+	/*
+	 * base numbers are the size or position when no resizing has taken place (i.e. the defaults)
+	 */
+	double baseX, baseY, resizeFactor;
+	double baseInfoLineThickness, baseExitLineWidth;
+	double baseWidth, baseHeight;
 	int runs;
-	QCanvasLine *infoLine;
-	QCanvasEllipse *outside;
-	void finishMe();
+	AntialisedLine *infoLine;
+	void finishMe(double width=0);
 };
 class BlackHoleObj : public Object
 {
 public:
 	BlackHoleObj() { m_name = i18n("Black Hole"); m__name = "blackhole"; }
-	virtual QCanvasItem *newObject(QCanvas *canvas) { return new BlackHole(canvas); }
+	virtual QGraphicsItem *newObject(QGraphicsItem * parent,  QGraphicsScene *scene) { return new BlackHole(parent, scene); }
 };
 
 class WallPoint;
-class Wall : public QCanvasLine, public CanvasItem
+class Wall : public QGraphicsLineItem, public CanvasItem
 {
 public:
-	Wall(QCanvas *canvas);
+	Wall( QGraphicsItem * parent, QGraphicsScene *scene, bool antialiasing=1);
 	virtual void aboutToDie();
 	double dampening;
 
 	void setAlwaysShow(bool yes);
-	virtual void setZ(double newz);
+	void paint(QPainter *p, const QStyleOptionGraphicsItem *style, QWidget *widget);
+	virtual void setZValue(double newz);
+	void resize(double resizeFactor);
+	void setBasePenWidth(double basePenWidth) { this->basePenWidth=basePenWidth; }
+	void setLine(const QLineF & line);
+	void setLine(qreal x1, qreal y1, qreal x2, qreal y2);
 	virtual void setPen(QPen p);
 	virtual bool collision(Ball *ball, long int id);
-	virtual void save(KConfig *cfg);
-	virtual void load(KConfig *cfg);
-	virtual void selectedItem(QCanvasItem *item);
+	virtual void save(KConfigGroup *cfgGroup);
+	virtual void load(KConfigGroup *cfgGroup);
+	virtual void selectedItem(QGraphicsItem *item);
 	virtual void editModeChanged(bool changed);
 	virtual void moveBy(double dx, double dy);
+	virtual void setPos(double x, double y);
 	virtual void setVelocity(double vx, double vy);
 	virtual void clean();
 
 	// must reimp because we gotta move the end items,
 	// and we do that in moveBy()
-	virtual void setPoints(int xa, int ya, int xb, int yb) { QCanvasLine::setPoints(xa, ya, xb, yb); moveBy(0, 0); }
+	virtual void setPoints(double xa, double ya, double xb, double yb) { setLine(xa, ya, xb, yb); moveBy(0, 0); }
 
-	virtual int rtti() const { return Rtti_Wall; }
-	virtual QPtrList<QCanvasItem> moveableItems() const;
+	virtual QList<QGraphicsItem *> moveableItems() const;
 	virtual void setGame(KolfGame *game);
 	virtual void setVisible(bool);
 
-	virtual QPointArray areaPoints() const;
+	QPointF startPointF() const { return QPointF(line().x1(), line().y1() ); }
+	QPointF endPointF() const { return QPointF(line().x2(), line().y2() ); }
+	QPoint startPoint() const { return QPoint((int)line().x1(), (int)line().y1() ); }
+	QPoint endPoint() const { return QPoint((int)line().x2(), (int)line().y2() ); }
+
+	void doAdvance();
+	virtual void updateBaseResizeInfo() {}
 
 protected:
 	WallPoint *startItem;
@@ -459,27 +535,39 @@ protected:
 	bool editing;
 
 private:
+	/*
+	 * base numbers are the size or position when no resizing has taken place (i.e. the defaults)
+	 */
+	double resizeFactor;
+	double basePenWidth;
+	bool antialiasing;
 	long int lastId;
 
 	friend class WallPoint;
 };
-class WallPoint : public QCanvasEllipse, public CanvasItem
+class WallPoint : public QGraphicsEllipseItem, public CanvasItem
 {
 public:
-	WallPoint(bool start, Wall *wall, QCanvas *canvas);
+	WallPoint(bool start, Wall *wall, QGraphicsItem * parent, QGraphicsScene *scene);
 	void setAlwaysShow(bool yes) { alwaysShow = yes; updateVisible(); }
 	virtual void editModeChanged(bool changed);
 	virtual void moveBy(double dx, double dy);
-	virtual int rtti() const { return Rtti_WallPoint; }
 	virtual bool deleteable() const { return false; }
 	virtual bool collision(Ball *ball, long int id);
 	virtual CanvasItem *itemToDelete() { return wall; }
 	virtual void clean();
 	virtual Config *config(QWidget *parent) { return wall->config(parent); }
-	void dontMove() { dontmove = true; };
+	void dontMove() { dontmove = true; }
 	void updateVisible();
 
+	void setSize(double width, double height) { setRect(rect().x(), rect().y(), width, height); }
+	double width() { return rect().width(); }
+	double height() { return rect().height(); }
+
 	Wall *parentWall() { return wall; }
+	void updateBaseResizeInfo();
+
+	double baseX, baseY, resizeFactor;
 
 protected:
 	Wall *wall;
@@ -498,16 +586,17 @@ class WallObj : public Object
 {
 public:
 	WallObj() { m_name = i18n("Wall"); m__name = "wall"; }
-	virtual QCanvasItem *newObject(QCanvas *canvas) { return new Wall(canvas); }
+	virtual QGraphicsItem *newObject( QGraphicsItem * parent, QGraphicsScene *scene) { return new Wall(parent, scene); }
 };
 
-class Putter : public QCanvasLine, public CanvasItem
+class Putter : public QGraphicsLineItem, public CanvasItem
 {
 public:
-	Putter(QCanvas *canvas);
+	Putter(QGraphicsScene *scene);
+	void resize(double resizeFactor);
 	void go(Direction, Amount amount = Amount_Normal);
-	void setOrigin(int x, int y);
-	int curLen() const { return len; }
+	void setOrigin(double x, double y);
+	double curLen() const { return guideLineLength; }
 	double curAngle() const { return angle; }
 	int curDeg() const { return rad2deg(angle); }
 	virtual void showInfo();
@@ -515,28 +604,38 @@ public:
 	void setAngle(double news) { angle = news; finishMe(); }
 	void setDeg(int news) { angle = deg2rad(news); finishMe(); }
 	double curMaxAngle() const { return maxAngle; }
-	virtual int rtti() const { return Rtti_Putter; }
 	virtual void setVisible(bool yes);
 	void saveAngle(Ball *ball) { angleMap[ball] = angle; }
 	void setAngle(Ball *ball);
-	void resetAngles() { angleMap.clear(); setZ(999999); }
+	void resetAngles() { angleMap.clear(); setZValue(999999); }
 	virtual bool canBeMovedByOthers() const { return true; }
 	virtual void moveBy(double dx, double dy);
 	void setShowGuideLine(bool yes);
 
+
 private:
-	QPoint midPoint;
+	QPointF midPoint;
 	double maxAngle;
 	double angle;
 	double oneDegree;
 	QMap<Ball *, double> angleMap;
-	int len;
+	/*
+	 * base numbers are the size or position when no resizing has taken place (i.e. the defaults)
+	 */
+	double guideLineLength, baseGuideLineLength;
+	double baseGuideLineThickness;
+	double basePutterThickness;
+	double basePutterWidth, putterWidth;
+	/*
+	 * resizeFactor is the number to multiply base numbers by to get their resized value (i.e. if it is 1 then use default size, if it is >1 then everything needs to be bigger, and if it is <1 then everything needs to be smaller)
+	 */
+	double resizeFactor;
 	void finishMe();
-	int putterWidth;
-	QCanvasLine *guideLine;
+	QGraphicsLineItem *guideLine;
 	bool m_showGuideLine;
 };
 
+
 class Bridge;
 class BridgeConfig : public Config
 {
@@ -561,29 +660,31 @@ protected:
 private:
 	Bridge *bridge;
 };
-class Bridge : public QCanvasRectangle, public CanvasItem, public RectItem
+class Bridge : public QGraphicsRectItem, public CanvasItem, public RectItem
 {
 public:
-	Bridge(QRect rect, QCanvas *canvas);
+	Bridge(const QRect &rect, QGraphicsItem *parent, QGraphicsScene *scene, const QString &type);
+	void paint(QPainter *p, const QStyleOptionGraphicsItem *style, QWidget *widget=0);
 	virtual bool collision(Ball *ball, long int id);
+	virtual void resize(double resizeFactor);
 	virtual void aboutToDie();
 	virtual void editModeChanged(bool changed);
 	virtual void moveBy(double dx, double dy);
-	virtual void load(KConfig *cfg);
-	virtual void save(KConfig *cfg);
+	virtual void load(KConfigGroup *cfgGroup);
+	virtual void save(KConfigGroup *cfgGroup);
 	virtual bool vStrut() const { return true; }
-	void doLoad(KConfig *cfg);
-	void doSave(KConfig *cfg);
-	virtual void newSize(int width, int height);
+	void doLoad(KConfigGroup *cfgGroup);
+	void doSave(KConfigGroup *cfgGroup);
+	virtual void newSize(double width, double height);
 	virtual void setGame(KolfGame *game);
 	virtual Config *config(QWidget *parent) { return new BridgeConfig(this, parent); }
-	void setSize(int width, int height);
-	virtual QPtrList<QCanvasItem> moveableItems() const;
+	void setSize(double width, double height);
+	virtual QList<QGraphicsItem *> moveableItems() const;
 
-	void setWallColor(QColor color);
+	void setWallColor(const QColor &color);
 	QPen wallPen() const { return topWall->pen(); }
 
-	double wallZ() const { return topWall->z(); }
+	double wallZ() const { return topWall->zValue(); }
 	void setWallZ(double);
 
 	void setTopWallVisible(bool yes) { topWall->setVisible(yes); }
@@ -594,8 +695,25 @@ public:
 	bool botWallVisible() const { return botWall->isVisible(); }
 	bool leftWallVisible() const { return leftWall->isVisible(); }
 	bool rightWallVisible() const { return rightWall->isVisible(); }
+	
+	double width() {return QGraphicsRectItem::rect().width(); }
+	double height() {return QGraphicsRectItem::rect().height(); }
+
+	virtual void updateBaseResizeInfo();
 
 protected:
+	bool pixmapInitialised;
+	QPixmap pixmap;
+	QString type;
+	/*
+	 * base numbers are the size or position when no resizing has taken place (i.e. the defaults)
+	 */
+	double baseX, baseY, baseWidth, baseHeight;
+	double baseTopWallX, baseTopWallY;
+	double baseBotWallX, baseBotWallY;
+	double baseLeftWallX, baseLeftWallY;
+	double baseRightWallX, baseRightWallY;
+	double resizeFactor;
 	Wall *topWall;
 	Wall *botWall;
 	Wall *leftWall;
@@ -606,7 +724,7 @@ class BridgeObj : public Object
 {
 public:
 	BridgeObj() { m_name = i18n("Bridge"); m__name = "bridge"; }
-	virtual QCanvasItem *newObject(QCanvas *canvas) { return new Bridge(QRect(0, 0, 80, 40), canvas); }
+	virtual QGraphicsItem *newObject(QGraphicsItem *parent, QGraphicsScene *scene) { return new Bridge(QRect(0, 0, 80, 40), parent, scene, "bridge"); }
 };
 
 class Sign;
@@ -626,16 +744,21 @@ private:
 class Sign : public Bridge
 {
 public:
-	Sign(QCanvas *canvas);
+	Sign(QGraphicsItem * parent, QGraphicsScene *scene);
+	void resize(double resizeFactor);
 	void setText(const QString &text);
 	QString text() const { return m_text; }
-	virtual void draw(QPainter &painter);
+	virtual void paint(QPainter *painter, const QStyleOptionGraphicsItem *, QWidget *);
 	virtual bool vStrut() const { return false; }
 	virtual Config *config(QWidget *parent) { return new SignConfig(this, parent); }
-	virtual void save(KConfig *cfg);
-	virtual void load(KConfig *cfg);
+	virtual void save(KConfigGroup *cfgGroup);
+	virtual void load(KConfigGroup *cfgGroup);
 
 protected:
+	/*
+	 * base numbers are the size or position when no resizing has taken place (i.e. the defaults)
+	 */
+	double baseFontPixelSize, fontPixelSize;
 	QString m_text;
 	QString m_untranslatedText;
 };
@@ -643,20 +766,22 @@ class SignObj : public Object
 {
 public:
 	SignObj() { m_name = i18n("Sign"); m__name = "sign"; }
-	virtual QCanvasItem *newObject(QCanvas *canvas) { return new Sign(canvas); }
+	virtual QGraphicsItem *newObject(QGraphicsItem * parent, QGraphicsScene *scene) { return new Sign(parent, scene); }
 };
 
 class Windmill;
 class WindmillGuard : public Wall
 {
 public:
-	WindmillGuard(QCanvas *canvas) : Wall(canvas) {};
-	void setBetween(int newmin, int newmax) { max = newmax; min = newmin; }
+	WindmillGuard(QGraphicsItem * parent, QGraphicsScene *scene) : Wall(parent, scene, false) {}
+	void setBetween(double newmin, double newmax) { max = newmax; min = newmin; }
 	virtual void advance(int phase);
+	double getMax() { return max; }
+	double getMin() { return min; }
 
 protected:
-	int max;
-	int min;
+	double max;
+	double min;
 };
 class WindmillConfig : public BridgeConfig
 {
@@ -675,33 +800,41 @@ private:
 class Windmill : public Bridge
 {
 public:
-	Windmill(QRect rect, QCanvas *canvas);
+	Windmill(const QRect &rect, QGraphicsItem * parent, QGraphicsScene *scene);
 	virtual void aboutToDie();
-	virtual void newSize(int width, int height);
-	virtual void save(KConfig *cfg);
-	virtual void load(KConfig *cfg);
+	virtual void newSize(double width, double height);
+	virtual void save(KConfigGroup *cfgGroup);
+	virtual void load(KConfigGroup *cfgGroup);
 	virtual void setGame(KolfGame *game);
 	virtual Config *config(QWidget *parent) { return new WindmillConfig(this, parent); }
-	void setSize(int width, int height);
+	void setSize(double width, double height);
+	virtual void resize(double resizeFactor);
 	virtual void moveBy(double dx, double dy);
-	void setSpeed(int news);
-	int curSpeed() const { return speed; }
+	void setSpeed(double news);
+	double curSpeed() const { return speed; }
 	void setBottom(bool yes);
 	bool bottom() const { return m_bottom; }
+	void updateBaseResizeInfo();
 
 protected:
 	WindmillGuard *guard;
 	Wall *left;
 	Wall *right;
+	/*
+	 * base numbers are the size or position when no resizing has taken place (i.e. the defaults)
+	 */
+	double baseGuardX, baseGuardY, baseGuardMin, baseGuardMax, baseGuardSpeed;
+	double baseLeftX, baseLeftY, baseRightX, baseRightY;
+	double resizeFactor;
 	int speedfactor;
-	int speed;
+	double speed;
 	bool m_bottom;
 };
 class WindmillObj : public Object
 {
 public:
 	WindmillObj() { m_name = i18n("Windmill"); m__name = "windmill"; }
-	virtual QCanvasItem *newObject(QCanvas *canvas) { return new Windmill(QRect(0, 0, 80, 40), canvas); }
+	virtual QGraphicsItem *newObject(QGraphicsItem * parent, QGraphicsScene *scene) { return new Windmill(QRect(0, 0, 80, 40), parent, scene); }
 };
 
 class HoleInfo;
@@ -755,30 +888,30 @@ private:
 	int m_lowestMaxStrokes;
 };
 
-class StrokeCircle : public QCanvasItem
+class StrokeCircle : public QGraphicsItem
 {
 public:
-	StrokeCircle(QCanvas *canvas);
+	StrokeCircle(QGraphicsItem *parent, QGraphicsScene *scene);
 
+	void resize(double resizeFactor);
 	void setValue(double v);
 	double value();
 	void setMaxValue(double m);
-	void setSize(int w, int h);
-	void setThickness(int t);
-	int thickness() const;
-	int width() const;
-	int height() const;
-	virtual void draw(QPainter &p);
-	virtual QRect boundingRect() const;
-	virtual bool collidesWith(const QCanvasItem*) const;
-	virtual bool collidesWith(const QCanvasSprite*, const QCanvasPolygonalItem*, const QCanvasRectangle*, const QCanvasEllipse*, const QCanvasText*) const;
+	void setSize(double w, double h);
+	void setThickness(double t);
+	double thickness() const;
+	double width() const;
+	double height() const;
+	virtual void paint (QPainter *, const QStyleOptionGraphicsItem *, QWidget *);
+	virtual QRectF boundingRect() const;
+	virtual bool collidesWithItem(const QGraphicsItem*, Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const;
 
 private:
 	double dvalue, dmax;
-	int ithickness, iwidth, iheight;
+	double ithickness, iwidth, iheight;
 };
 
-struct KDE_EXPORT CourseInfo
+struct KOLFLIB_EXPORT CourseInfo
 {
 	CourseInfo(const QString &_name, const QString &_untranslatedName, const QString &_author, unsigned int _holes, unsigned int _par) { name = _name; untranslatedName = _untranslatedName, author = _author; holes = _holes; par = _par; }
 	CourseInfo();
@@ -790,20 +923,19 @@ struct KDE_EXPORT CourseInfo
 	unsigned int par;
 };
 
-class KDE_EXPORT KolfGame : public QCanvasView
+class KOLFLIB_EXPORT KolfGame : public QGraphicsView
 {
 	Q_OBJECT
 
 public:
-	KolfGame(ObjectList *obj, PlayerList *players, QString filename, QWidget *parent=0, const char *name=0 );
+	KolfGame(ObjectList *obj, PlayerList *players, const QString &filename, QWidget *parent=0);
 	~KolfGame();
 	void setObjects(ObjectList *obj) { this->obj = obj; }
 	void setFilename(const QString &filename);
 	QString curFilename() const { return filename; }
 	void emitLargestHole() { emit largestHole(highestHole); }
-	QCanvas *canvas() const { return course; }
-	void removeItem(QCanvasItem *item) { items.setAutoDelete(false); items.removeRef(item); }
-	// returns whether it was a cancel
+	QGraphicsScene *scene() const { return course; }
+	void removeItem(QGraphicsItem *item) { items.removeAll(item); }
 	bool askSave(bool);
 	bool isEditing() const { return editing; }
 	int currentHole() { return curHole; }
@@ -814,8 +946,7 @@ public:
 	void updateMouse();
 	void ballMoved();
 	void updateHighlighter();
-	void updateCourse() { course->update(); }
-	QCanvasItem *curSelectedItem() const { return selectedItem; }
+	QGraphicsItem *curSelectedItem() const { return selectedItem; }
 	void setBorderWalls(bool);
 	void setInPlay(bool yes) { inPlay = yes; }
 	bool isInPlay() { return inPlay; }
@@ -825,8 +956,9 @@ public:
 	void hidePutter() { putter->setVisible(false); }
 	void ignoreEvents(bool ignore) { m_ignoreEvents = ignore; }
 
-	static void scoresFromSaved(KConfig *, PlayerList &players);
+	static void scoresFromSaved(KConfig*, PlayerList &players);
 	static void courseInfo(CourseInfo &info, const QString &filename);
+	KolfSvgRenderer *renderer;
 
 public slots:
 	void pause();
@@ -843,11 +975,11 @@ public slots:
 	void firstHole();
 	void lastHole();
 	void randHole();
-	void playSound(QString file, double vol = 1);
+	void playSound(const QString &file, float vol = 1);
 	void showInfoDlg(bool = false);
 	void resetHole();
 	void clearHole();
-	void print(KPrinter &);
+	void print(QPrinter &, bool printTitle);
 	void setShowInfo(bool yes);
 	void toggleShowInfo();
 	void updateShowInfo();
@@ -869,7 +1001,6 @@ signals:
 	void largestHole(int);
 	void scoreChanged(int, int, int);
 	void newPlayersTurn(Player *);
-	void playerHoled(Player *);
 	void newSelectedItem(CanvasItem *);
 	void checkEditing();
 	void editingStarted();
@@ -888,9 +1019,8 @@ private slots:
 	void fastTimeout();
 	void putterTimeout();
 	void autoSaveTimeout();
-	void addItemsToMoveableList(QPtrList<QCanvasItem>);
+	void addItemsToMoveableList(QList<QGraphicsItem *>);
 	void addItemToFastAdvancersList(CanvasItem *);
-	void hideInfo();
 
 	void emitMax();
 
@@ -907,15 +1037,24 @@ protected:
 	void keyPressEvent(QKeyEvent *e);
 	void keyReleaseEvent(QKeyEvent *e);
 
+	/*
+	 * resizes view to make sure it is square and calls resizeAllItems
+	 */
+	void resizeEvent(QResizeEvent *);
+	/*
+	 * resizes and moves all items in the game
+	 */
+	void resizeAllItems(double resizeFactor, bool resizeBorderWalls=1);
+
 	QPoint viewportToViewport(const QPoint &p);
 
 private:
-	QCanvas *course;
+	QGraphicsScene *course;
 	Putter *putter;
 	PlayerList *players;
 	PlayerList::Iterator curPlayer;
 	Ball *whiteBall;
-	StrokeCircle *strokeCircle;
+	StrokeCircle *strokeCircle; 
 
 	QTimer *timer;
 	QTimer *autoSaveTimer;
@@ -924,9 +1063,9 @@ private:
 	bool regAdv;
 
 	ObjectList *obj;
-	QPtrList<QCanvasItem> items;
-	QPtrList<QCanvasItem> extraMoveable;
-	QPtrList<Wall> borderWalls;
+	QList<QGraphicsItem *> items;
+	QList<QGraphicsItem *> extraMoveable;
+	QList<Wall *> borderWalls;
 
 	int timerMsec;
 	int autoSaveMsec;
@@ -970,23 +1109,23 @@ private:
 	QPoint storedMousePos;
 	bool moving;
 	bool dragging;
-	QCanvasItem *movingItem;
-	QCanvasItem *selectedItem;
-	QCanvasRectangle *highlighter;
+	QGraphicsItem *movingItem;
+	CanvasItem *movingCanvasItem;
+	QGraphicsItem *selectedItem;
+	QGraphicsRectItem *highlighter;
+	
+	//For intro banner
+	QGraphicsPixmapItem *banner;
 
-	// sound
-	KArtsDispatcher artsDispatcher;
-	KArtsServer artsServer;
-	QPtrList<KPlayObject> oldPlayObjects;
+#ifdef SOUND
+    Phonon::MediaObject *m_player;
+#endif
 	bool m_sound;
-	bool soundedOnce;
 	QString soundDir;
 
 	bool m_ignoreEvents;
 
 	HoleInfo holeInfo;
-	QCanvasText *infoText;
-	void showInfo();
 	StateDB stateDB;
 
 	BallStateList ballStateList;
@@ -1005,8 +1144,9 @@ private:
 	bool infoShown;
 
 	KConfig *cfg;
+	KConfigGroup cfgGroup;
 
-	inline void addBorderWall(QPoint start, QPoint end);
+	inline void addBorderWall(const QPoint &start, const QPoint &end);
 	void shotStart();
 	void startBall(const Vector &vector);
 
@@ -1017,7 +1157,7 @@ private:
 	bool m_useMouse;
 	bool m_useAdvancedPutting;
 
-	QPtrList<CanvasItem> fastAdvancers;
+	QList<CanvasItem *> fastAdvancers;
 	bool fastAdvancedExist;
 
 	QString playerWhoMaxed;
