@@ -2,7 +2,7 @@
 
   mod3.cpp  implements a patience card game
 
-     Copyright (C) 1997  Rodolfo Borges
+     Copyright 1997 Rodolfo Borges <barrett@labma.ufrj.br>
 
  * Permission to use, copy, modify, and distribute this software and its
  * documentation for any purpose and without fee is hereby granted,
@@ -25,18 +25,18 @@
 
 #include "dealer.h"
 
-class Mod3 : public Dealer
+class Mod3 : public DealerScene
 {
+    friend class Mod3Solver;
+
     Q_OBJECT
 
 public:
-    Mod3( KMainWindow* parent=0, const char* name=0);
+    Mod3( );
 
     void deal();
 
     virtual void restart();
-    virtual bool isGameLost() const;
-    virtual bool startAutoDrop();
 
 public slots:
     void deckClicked(Card *c);
@@ -51,8 +51,6 @@ private: // functions
     void         dealRow(int row);
 
 private:
-    Deck  *deck;
-
     Pile  *stack[4][8];
     Pile  *aces;
 };
