@@ -23,17 +23,21 @@
 #ifndef __PWIDGET__H__
 #define __PWIDGET__H__
 
-#include <kmainwindow.h>
-
-class Dealer;
+#include <kxmlguiwindow.h>
+//Added by qt3to4:
+#include <QPixmap>
+#include <QLabel>
+#include <QShowEvent>
+#include <krecentfilesaction.h>
+class PatienceView;
 class KToggleAction;
 class KSelectAction;
 class KRecentFilesAction;
-class KAction;
-class QWidgetStack;
+class QAction;
 class QLabel;
+class cardMap;
 
-class pWidget: public KMainWindow {
+class pWidget: public KXmlGuiWindow {
     Q_OBJECT
 
 public:
@@ -42,49 +46,48 @@ public:
 
 public slots:
     void undoMove();
-    void changeBackside();
-    void animationChanged();
     void newGameType();
+    void slotNewGameType();
     void restart();
 
     void openGame();
-    void openGame(const KURL &url);
+    void openGame(const KUrl &url);
     void saveGame();
 
     void newGame();
     void chooseGame();
     void undoPossible(bool poss);
-    void gameWon(bool withhelp);
     void gameLost();
-    void changeWallpaper();
     void slotGameInfo(const QString &);
     void slotUpdateMoves();
     void helpGame();
     void enableAutoDrop();
-	 void showStats();
+    void showStats();
+
+    void slotGameSolverStart();
+    void slotGameSolverWon();
+    void slotGameSolverLost();
+    void slotGameSolverUnknown();
+    void slotPickRandom();
+    void slotSelectDeck();
 
 private:
     void setGameCaption();
-    void setBackSide(const QString &deck, const QString &dir);
     virtual void showEvent(QShowEvent *e);
 
 private:
     // Members
 
-    Dealer         *dill;	// The current patience
+    PatienceView   *dill;
 
     KSelectAction  *games;
-    KSelectAction  *wallpapers;
-    KAction        *backs;
-    KAction        *undo;
-    KToggleAction  *animation;
+    QAction        *undo;
     KToggleAction  *dropaction;
-    KAction        *stats;
+    QAction        *stats;
 
     QPixmap         background;
-    QColor          midcolor;
-    QStringList     wallpaperlist;
     KRecentFilesAction  *recent;
+    cardMap        *m_cards; // possibly move to PatienceView
 };
 
 #endif
