@@ -1,7 +1,7 @@
 /*
     This file is part of the KDE games library
     Copyright (C) 2001 Andreas Beckermann (b_mann@gmx.de)
-    Copyright (C) 2001 Martin Heni (martin@heni-online.de)
+    Copyright (C) 2001 Martin Heni (kde at heni-online.de)
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -18,23 +18,27 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <qlayout.h>
-#include <qvbox.h>
+#include "kgamedialog.h"
+
+#include <QLayout>
+//Added by qt3to4:
+#include <QVBoxLayout>
+#include <QList>
 
 #include <klocale.h>
+#include <kvbox.h>
+#include <kdebug.h>
 
 #include "kgame.h"
 #include "kplayer.h"
 #include "kgamedialogconfig.h"
 
-#include "kgamedialog.h"
-
 #include "kgamedialog.moc"
 
 class KGameDialogPrivate
 {
 public:
-	KGameDialogPrivate() 
+	KGameDialogPrivate()
 	{
 		mGamePage = 0;
 		mNetworkPage = 0;
@@ -48,15 +52,15 @@ public:
 		mGame = 0;
 	}
 
-	QVBox* mGamePage;
-	QVBox* mNetworkPage;
-	QVBox* mMsgServerPage;// unused here?
+	KVBox* mGamePage;
+	KVBox* mNetworkPage;
+	KVBox* mMsgServerPage;// unused here?
 	QVBoxLayout* mTopLayout;
 	KGameDialogNetworkConfig* mNetworkConfig;
 	KGameDialogGeneralConfig* mGameConfig;
 
 // a list of all config widgets added to this dialog
-	QPtrList<KGameDialogConfig> mConfigWidgets;
+	QList<KGameDialogConfig*> mConfigWidgets;
 
 // just pointers:
 	KPlayer* mOwner;
@@ -65,29 +69,42 @@ public:
 
 KGameDialog::KGameDialog(KGame* g, KPlayer* owner, const QString& title,
 		QWidget* parent, bool modal)
-	: KDialogBase(Tabbed, title, Ok|Default|Apply,
-	Ok, parent, 0, modal, true)
+    : KPageDialog(parent),
+      d( new KGameDialogPrivate )
 {
- init(g, owner);
+	setCaption(title);
+	setButtons(Ok|Default|Apply); 
+	setDefaultButton(Ok);
+	setFaceType(KPageDialog::Tabbed);
+	setModal(modal);
+
+        init(g, owner);
 }
 
-KGameDialog::KGameDialog(KGame* g, KPlayer* owner, const QString& title, 
+KGameDialog::KGameDialog(KGame* g, KPlayer* owner, const QString& title,
 		QWidget* parent, long initConfigs, int chatMsgId, bool modal)
-	: KDialogBase(Tabbed, title, Ok|Default|Apply,
-	Ok, parent, 0, modal, true)
+    : KPageDialog(parent),
+      d( new KGameDialogPrivate )
 {
+    setCaption(title);
+    setButtons(Ok|Default|Apply);
+    setDefaultButton(Ok);
+    setFaceType(KPageDialog::Tabbed);
+    setModal(modal);
  init(g, owner);
  if ((ConfigOptions)initConfigs!=NoConfig) {
 	initDefaultDialog((ConfigOptions)initConfigs, chatMsgId);
  }
+ connect(this,SIGNAL(okClicked()),this,SLOT(slotOk()));
+ connect(this,SIGNAL(defaultClicked()),this,SLOT(slotDefault()));
+ connect(this,SIGNAL(applyClicked()),this,SLOT(slotApply()));
 }
 
 void KGameDialog::init(KGame* g, KPlayer* owner)
 {
 //AB: do we need a "Cancel" Button? currently removed
 
-// kdDebug(11001) << k_funcinfo << ": this=" << this << endl;
- d = new KGameDialogPrivate;
+// kDebug(11001) << ": this=" << this;
 
  setOwner(owner);
  setKGame(g);
@@ -101,7 +118,7 @@ void KGameDialog::init(KGame* g, KPlayer* owner)
 void KGameDialog::initDefaultDialog(ConfigOptions initConfigs, int chatMsgId)
 {
  if (initConfigs & GameConfig) {
-	kdDebug() << "add gameconf" << endl;
+	kDebug() << "add gameconf";
 	addGameConfig(new KGameDialogGeneralConfig(0));
  }
  if (initConfigs & NetworkConfig) {
@@ -133,9 +150,9 @@ void KGameDialog::initDefaultDialog(ConfigOptions initConfigs, int chatMsgId)
 
 KGameDialog::~KGameDialog()
 {
-// kdDebug(11001) << "DESTRUCT KGameDialog" << this << endl;
- d->mConfigWidgets.setAutoDelete(true);
- d->mConfigWidgets.clear();
+// kDebug(11001) << "DESTRUCT KGameDialog" << this;
+ while (!d->mConfigWidgets.isEmpty())
+         delete d->mConfigWidgets.takeFirst();
  delete d;
 }
 
@@ -165,7 +182,7 @@ void KGameDialog::addMsgServerConfig(KGameDialogMsgServerConfig* msgConf)
  d->mMsgServerPage = addConfigPage(msgConf, i18n("&Message Server"));
 }
 
-void KGameDialog::addChatWidget(KGameDialogChatConfig* chat, QVBox* parent)
+void KGameDialog::addChatWidget(KGameDialogChatConfig* chat, KVBox* parent)
 {
  if (!chat) {
 	return;
@@ -174,13 +191,13 @@ void KGameDialog::addChatWidget(KGameDialogChatConfig* chat, QVBox* parent)
 	parent = d->mGamePage;
  }
  if (!parent) {
-	kdError(11001) << "cannot add chat widget without page" << endl;
+	kError(11001) << "cannot add chat widget without page";
 	return;
  }
  addConfigWidget(chat, parent);
 }
 
-void KGameDialog::addConnectionList(KGameDialogConnectionConfig* c, QVBox* parent)
+void KGameDialog::addConnectionList(KGameDialogConnectionConfig* c, KVBox* parent)
 {
  if (!c) {
 	return;
@@ -189,15 +206,15 @@ void KGameDialog::addConnectionList(KGameDialogConnectionConfig* c, QVBox* paren
 	parent = d->mNetworkPage;
  }
  if (!parent) {
-	kdError(11001) << "Cannot add connection list without page" << endl;
+	kError(11001) << "Cannot add connection list without page";
 	return;
  }
  addConfigWidget(c, parent);
 }
 
-QVBox *KGameDialog::configPage(ConfigOptions which)
+KVBox *KGameDialog::configPage(ConfigOptions which)
 {
- QVBox *box = 0;
+ KVBox *box = 0;
  switch(which)
  {
 	case NetworkConfig:
@@ -210,18 +227,19 @@ QVBox *KGameDialog::configPage(ConfigOptions which)
 		box = d->mMsgServerPage;
 		break;
 	default:
-		kdError(11001) << k_funcinfo << ": Parameter " << which << " not supported" << endl;
+		kError(11001) << ": Parameter" << which << "not supported";
  }
  return box;
 }
 
-QVBox* KGameDialog::addConfigPage(KGameDialogConfig* widget, const QString& title)
+KVBox* KGameDialog::addConfigPage(KGameDialogConfig* widget, const QString& title)
 {
  if (!widget) {
-	kdError(11001) << "Cannot add NULL config widget" << endl;
+	kError(11001) << "Cannot add NULL config widget";
 	return 0;
  }
- QVBox* page = addVBoxPage(title);
+ KVBox* page = new KVBox();
+ addPage(page,title);
  addConfigWidget(widget, page);
  return page;
 }
@@ -229,25 +247,26 @@ QVBox* KGameDialog::addConfigPage(KGameDialogConfig* widget, const QString& titl
 void KGameDialog::addConfigWidget(KGameDialogConfig* widget, QWidget* parent)
 {
  if (!widget) {
-	kdError(11001) << "Cannot add NULL config widget" << endl;
+	kError(11001) << "Cannot add NULL config widget";
 	return;
  }
  if (!parent) {
-	kdError(11001) << "Cannot reparent to NULL widget" << endl;
+	kError(11001) << "Cannot reparent to NULL widget";
 	return;
  }
-// kdDebug(11001) << "reparenting widget" << endl;
- widget->reparent(parent, QPoint(0,0));
+// kDebug(11001) << "reparenting widget";
+ widget->setParent(parent);
+ widget->move(QPoint(0,0));
  d->mConfigWidgets.append(widget);
  connect(widget, SIGNAL(destroyed(QObject*)), this, SLOT(slotRemoveConfigWidget(QObject*)));
  if (!d->mGame) {
-	kdWarning(11001) << "No game has been set!" << endl;
+	kWarning(11001) << "No game has been set!";
  } else {
 	widget->setKGame(d->mGame);
 	widget->setAdmin(d->mGame->isAdmin());
  }
  if (!d->mOwner) {
-	kdWarning(11001) << "No player has been set!" << endl;
+	kWarning(11001) << "No player has been set!";
  } else {
 	widget->setOwner(d->mOwner);
  }
@@ -269,7 +288,7 @@ void KGameDialog::slotDefault()
  if (!d->mGame) {
 	return;
  }
- 
+
 //TODO *only*  call setKGame/setOwner for the *current* page!!
  setKGame(d->mGame);
  setOwner(d->mOwner);
@@ -285,12 +304,12 @@ void KGameDialog::setOwner(KPlayer* owner)
 {
 //AB: note: NULL player is ok!
  d->mOwner = owner;
- for (int unsigned i = 0; i < d->mConfigWidgets.count(); i++) {
+ for (int i = 0; i < d->mConfigWidgets.count(); i++) {
 	if (d->mConfigWidgets.at(i)) {
 		d->mConfigWidgets.at(i)->setOwner(d->mOwner);
 		//TODO: hide playerName in KGameDialogGeneralConfig
 	} else {
-		kdError(11001) << "NULL widget??" << endl;
+		kError(11001) << "NULL widget??";
 	}
  }
 }
@@ -301,20 +320,20 @@ void KGameDialog::setKGame(KGame* g)
 	disconnect(d->mGame, 0, this, 0);
  }
  d->mGame = g;
- for (int unsigned i = 0; i < d->mConfigWidgets.count(); i++) {
+ for (int i = 0; i < d->mConfigWidgets.count(); i++) {
 	d->mConfigWidgets.at(i)->setKGame(d->mGame);
  }
  if (d->mGame) {
 	setAdmin(d->mGame->isAdmin());
 	connect(d->mGame, SIGNAL(destroyed()), this, SLOT(slotUnsetKGame()));
-	connect(d->mGame, SIGNAL(signalAdminStatusChanged(bool)), 
+	connect(d->mGame, SIGNAL(signalAdminStatusChanged(bool)),
 			this, SLOT(setAdmin(bool)));
  }
 }
 
 void KGameDialog::setAdmin(bool admin)
 {
- for (int unsigned i = 0; i < d->mConfigWidgets.count(); i++) {
+ for (int i = 0; i < d->mConfigWidgets.count(); i++) {
 	d->mConfigWidgets.at(i)->setAdmin(admin);
  }
 }
@@ -325,23 +344,23 @@ void KGameDialog::slotUnsetKGame() // called when KGame is destroyed
 void KGameDialog::submitToKGame()
 {
  if (!d->mGame) {
-	kdError(11001) << k_funcinfo << ": no game has been set" << endl;
+	kError(11001) << ": no game has been set";
 	return;
  }
  if (!d->mOwner) {
-	kdError(11001) << k_funcinfo << ": no player has been set" << endl;
+	kError(11001) << ": no player has been set";
 	return;
  }
 
- for (int unsigned i = 0; i < d->mConfigWidgets.count(); i++) {
-// kdDebug(11001) << "submit to kgame " << i << endl;
+ for (int i = 0; i < d->mConfigWidgets.count(); i++) {
+// kDebug(11001) << "submit to kgame" << i;
 	d->mConfigWidgets.at(i)->submitToKGame(d->mGame, d->mOwner);
-// kdDebug(11001) << "done: submit to kgame " << i << endl;
+// kDebug(11001) << "done: submit to kgame" << i;
  }
 }
 
 void KGameDialog::slotRemoveConfigWidget(QObject* configWidget)
 {
- d->mConfigWidgets.removeRef((KGameDialogConfig*)configWidget);
+ d->mConfigWidgets.removeAll((KGameDialogConfig*)configWidget);
 }
 
